@@ -57,11 +57,17 @@ class Template(models.Model):
 
 
 class JournalManager(models.Manager):
-    def for_object(self, obj):
+    def for_object(self, obj, tag=None):
         '''Return Journal records linked to this object.'''
         content_type = ContentType.objects.get_for_model(obj)
-        return self.filter(objectdata__content_type=content_type,
-                objectdata__object_id=obj.pk)
+        if tag is None:
+            return self.filter(objectdata__content_type=content_type,
+                    objectdata__object_id=obj.pk)
+        else:
+            return self.filter(
+                    objectdata__tag__name=tag,
+                    objectdata__content_type=content_type,
+                    objectdata__object_id=obj.pk)
 
     def for_objects(self, objects):
         '''Return journal records linked to any of this objects.
